@@ -7,6 +7,6 @@
 # Invenio-Cli is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
-python -m check_manifest --ignore ".travis-*" && \
+python -m check_manifest --ignore ".*-requirements.txt" && \
 python -m sphinx.cmd.build -qnNW docs docs/_build/html && \
 python -m pytest
